@@ -36,5 +36,4 @@
 				(lambda (jid domain) 
 				  (ft-set-server! (domain->server domain))))))
 
-(and (not (string=? (ft-get-jid) "")) (not (string=? (ft-get-server) ""))
-     (ft-connect))
+(and (not (string=? (ft-get-jid) "")) (not (string=? (ft-get-server) "")) connect-handle (ft-connect))
